==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/geneflag.R <==
## Don't export.  For internal use only. ##


geneflag <- function(object, allele.names, marker, compare)
  {
    ## Use subset of object, if marker is provided.
    if(!missing(marker))
      {

        object <- object[match(marker,as.vector(markerNames(object)))]
      }


    ## If allele.names are provided, then use them
    if(missing(allele.names))
      {
        allele.names <- alleleLevels(object)
      }
    else if (!is.list(allele.names) ||
             length(allele.names) < nmarker(object) )
      {
        allele.names <- rep(list(allele.names), nmarker(object) )
      }

    
    ## Find the alleles
    allele.matrix <- alleles(object)
    
    retval <- data.frame(matrix(NA,
                                nrow=nrow(allele.matrix),
                                ncol=nmarker(object))
                         )

    colnames(retval) <- markerNames(object)
    if(!is.null(rownames(allele.matrix)))
      rownames(retval) <- rownames(allele.matrix)

    anames <- names(allele.names)
    
    ## Fill in the retval
    for(i in 1:nmarker(object))
      {
        index <- i*2-1

        if(is.null(anames))
          mnames <- i
        else
          mnames <- markerNames(object)[i]
        
        retval[,i] <- apply(
                            allele.matrix[,index:(index+1)],
                            1,
                            compare,
                            i=mnames,
                            allele.names=allele.names
                            )
      }
  retval    
  }

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/geneflag.R <==
## Don't export.  For internal use only. ##


geneflag <- function(object, allele.names, marker, compare)
  {
    ## Use subset of object, if marker is provided.
    if(!missing(marker))
      {

        object <- object[match(marker,as.vector(markerNames(object)))]
      }


    ## If allele.names are provided, then use them
    if(missing(allele.names))
      {
        allele.names <- alleleLevels(object)
      }
    else if (!is.list(allele.names) ||
             length(allele.names) < nmarker(object) )
      {
        allele.names <- rep(list(allele.names), nmarker(object) )
      }

    
    ## Find the alleles
    allele.matrix <- alleles(object)
    
    retval <- data.frame(matrix(NA,
                                nrow=nrow(allele.matrix),
                                ncol=nmarker(object))
                         )

    colnames(retval) <- markerNames(object)
    if(!is.null(rownames(allele.matrix)))
      rownames(retval) <- rownames(allele.matrix)

    anames <- names(allele.names)
    
    ## Fill in the retval
    for(i in 1:nmarker(object))
      {
        index <- i*2-1

        if(is.null(anames))
          mnames <- i
        else
          mnames <- markerNames(object)[i]
        
        retval[,i] <- apply(
                            allele.matrix[,index:(index+1), drop=FALSE],
                            1,
                            compare,
                            i=mnames,
                            allele.names=allele.names
                            )
      }
  retval    
  }
